/* Install - Install / UnInstall for Unit Converter */

PARSE ARG action
IF RxFuncQuery('SysLoadFuncs') THEN DO
    CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
    CALL SysLoadFuncs
END
CALL SysCls
action = TRANSLATE(LEFT(action,1))
SELECT
    WHEN action = 'I' THEN CALL InstallMe
    WHEN action = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL WhatAction
END
Exit /* End of Install.cmd */

/* WhatAction - no action selected */

WhatAction:     PROCEDURE

CALL SysCls
SAY 'Please enter installation parameter (I=Install, U=UnInstall, other=Enter):'
PARSE PULL action
SELECT
    WHEN TRANSLATE(LEFT(action,1)) = 'I' THEN CALL InstallMe
    WHEN TRANSLATE(LEFT(action,1)) = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL NoAction 'Installation failed.'
END
RETURN /* End of WhatAction */

/* NoAction - abort Install */

NoAction:   PROCEDURE

CALL SysCls
PARSE ARG noinstmsg
SAY noinstmsg
SAY 'Press Enter to exit ...'
PULL answer
CALL SysCls
Exit /* End of NoAction */

/* InstallMe - install Unit Converter */

InstallMe:  PROCEDURE

prgname = 'Unit Converter 0.95'
cfgfiles = 'Convert.exe CONVERT.DAT Conbmp32.dll ENGLISH.INI English.inf'
IF RIGHT(Directory(),2) = ':\' THEN DO
    SAY 'Problem! '||prgname||' can not be installed in root directory.'
    SAY 'Create directory for '||prgname||', copy files: '||cfgfiles||' there and start this procedure again.'
    SAY 'Press Enter to exit ...'
    PULL answer
    Exit
END

CALL SysCls
SAY 'Welcome to '||prgname||' Installation procedure!'
SAY ' '
SAY 'Note: French lanugage support and Swedish manual are not'
SAY 'included in this version. They will be added later.'
SAY ' '
SAY 'Your files are in directory: '||Directory()
SAY 'Program object for '||prgname||' will be created on your Desktop,'
SAY 'Press "Y" (and Enter) to start Installation, any other key to exit...'

PARSE PULL answer

IF TRANSLATE(LEFT(answer,1)) <> "Y" THEN DO
    CALL NoAction 'Installation aborted'
END

SAY ' '
SAY 'Checking files:'
DO i = 1 TO WORDS(cfgfiles)
    CALL SysFiletree Directory()||'\'||WORD(cfgfiles,i), 'chkfile', 'FO'
    SELECT
	WHEN chkfile.0 = 1 THEN SAY '- '||LEFT(WORD(cfgfiles,i),12)||' - OK'
	OTHERWISE CALL NoAction LEFT(WORD(cfgfiles,i),12)||' - Missing file. Installation failed!'
    END
END

SAY 'Writing values to CONVERT.INI'
CALL SysIni 'CONVERT.INI', 'Language', 'ENGLISH', 'English.inf'
CALL SysIni 'CONVERT.INI', 'Language', 'CROATIAN', 'English.inf'
CALL SysIni 'CONVERT.INI', 'Language', 'GERMAN', 'English.inf'
CALL SysIni 'CONVERT.INI', 'Language', 'SWEDISH', 'English.inf'
CALL SysIni 'CONVERT.INI', 'Settings', 'CurrLang', 'ENGLISH'
CALL SysIni 'CONVERT.INI', 'Settings', 'Color', '#255 255 255'
CALL SysIni 'CONVERT.INI', 'Settings', 'Font', '9.WarpSans'
CALL SysIni 'CONVERT.INI', 'Settings', 'Position', '90 60 480 360'
CALL SysIni 'CONVERT.INI', 'Settings', 'Precision', '15'
CALL SysIni 'CONVERT.INI', 'Settings', 'Decimals', '3'
CALL SysIni 'CONVERT.INI', 'Settings', 'Format', '0'
CALL SysIni 'CONVERT.INI', 'Settings', 'Symbol', '0'
CALL SysIni 'CONVERT.INI', 'Settings', 'Group', ' 1'
CALL SysIni 'CONVERT.INI', 'Settings', 'OnExit', '1'

ProgTitle = prgname
EXE = 'Convert.exe'
ICO = 'Convert.ico'
InstallDir = Directory()
WorkDir = Directory()
Setup = 'OBJECTID=<UNIT_CONVERTER_PROGRAM>;EXENAME='InstallDir'\'EXE';ICONFILE='InstallDir'\'ICO';STARTUPDIR='WorkDir''
Action = 'U'
dummy = SysCreateObject('WPProgram',ProgTitle,'<WP_DESKTOP>',Setup,Action)
SELECT
    WHEN dummy = 1 THEN SAY 'Creating '||prgname||' Program object - OK'
    OTHERWISE SAY 'Creating '||prgname||' Program object - Error!'
END

SAY ' '
SAY 'Installation finished! Press Enter to exit ...'
PULL answer
CALL SysCls
RETURN /* End of InstallMe */

/* UnInstallMe - uninstall Unit Converter */

UnInstallMe: PROCEDURE

prgname = 'Unit Converter 0.95'
CALL SysCls
SAY 'This is '||prgname||' UnInstallation procedure!'
SAY 'Your files are in directory: '||Directory()
SAY 'This procedure will destroy '||prgname||' Program object'
SAY 'Press "Y" (and Enter) to start UnInstall, any other key to exit...'
PULL answer
IF answer <> "Y" THEN DO
    CALL NoAction 'UnInstall terminated.'
END
SAY ' '
SAY 'Destroying Program object'
CALL SysDestroyObject '<UNIT_CONVERTER_PROGRAM>'
SAY ' '
SAY 'UnInstallation complete. You can delete files in directory '||Directory()
SAY 'To install '||prgname||' again, start Install I. Press Enter to exit...'
PULL answer
RETURN /* End of UnInstallMe */
